class _NoneType:
    def __call__(self, *args, **kwargs):
        return _NoneType()
    def __getattr__(self, *args, **kwargs):
        return _NoneType()
    def __lt__(self, *args, **kwargs):
        return _NoneType()
    def __le__(self, *args, **kwargs):
        return _NoneType()
    def __eq__(self, *args, **kwargs):
        return _NoneType()
    def __ne__(self, *args, **kwargs):
        return _NoneType()
    def __gt__(self, *args, **kwargs):
        return _NoneType()
    def __ge__(self, *args, **kwargs):
        return _NoneType()
    def __repr__(self, *args, **kwargs):
        return "This is a fake object. Actual bpy cannot be used outside of blender"
    def __str__(self, *args, **kwargs):
        return "This is a fake object. Actual bpy cannot be used outside of blender"
    def __bytes__(self, *args, **kwargs):
        return b"This is a fake object. Actual bpy cannot be used outside of blender"
    def __format__(self, *args, **kwargs):
        return _NoneType()
    def __hash__(self, *args, **kwargs):
        return hash("This is a fake object. Actual bpy cannot be used outside of blender")
    def __bool__(self, *args, **kwargs):
        return True
    def __len__(self, *args, **kwargs):
        return 0
    def __iter__(self, *args, **kwargs):
        return _NoneType()
    def __reversed__(self, *args, **kwargs):
        return _NoneType()
    def __add__(self, *args, **kwargs):
        return _NoneType()
    def __sub__(self, *args, **kwargs):
        return _NoneType()
    def __mul__(self, *args, **kwargs):
        return _NoneType()
    def __matmul__(self, *args, **kwargs):
        return _NoneType()
    def __truediv__(self, *args, **kwargs):
        return _NoneType()
    def __floordiv__(self, *args, **kwargs):
        return _NoneType()
    def __mod__(self, *args, **kwargs):
        return _NoneType()
    def __divmod__(self, *args, **kwargs):
        return _NoneType()
    def __pow__(self, *args, **kwargs):
        return _NoneType()
    def __lshift__(self, *args, **kwargs):
        return _NoneType()
    def __rshift__(self, *args, **kwargs):
        return _NoneType()
    def __and__(self, *args, **kwargs):
        return _NoneType()
    def __xor__(self, *args, **kwargs):
        return _NoneType()
    def __or__(self, *args, **kwargs):
        return _NoneType()
    def __radd__(self, *args, **kwargs):
        return _NoneType()
    def __rsub__(self, *args, **kwargs):
        return _NoneType()
    def __rmul__(self, *args, **kwargs):
        return _NoneType()
    def __rmatmul__(self, *args, **kwargs):
        return _NoneType()
    def __rtruediv__(self, *args, **kwargs):
        return _NoneType()
    def __rfloordiv__(self, *args, **kwargs):
        return _NoneType()
    def __rmod__(self, *args, **kwargs):
        return _NoneType()
    def __rdivmod__(self, *args, **kwargs):
        return _NoneType()
    def __rpow__(self, *args, **kwargs):
        return _NoneType()
    def __rlshift__(self, *args, **kwargs):
        return _NoneType()
    def __rrshift__(self, *args, **kwargs):
        return _NoneType()
    def __rand__(self, *args, **kwargs):
        return _NoneType()
    def __rxor__(self, *args, **kwargs):
        return _NoneType()
    def __ror__(self, *args, **kwargs):
        return _NoneType()
    def __iadd__(self, *args, **kwargs):
        return _NoneType()
    def __isub__(self, *args, **kwargs):
        return _NoneType()
    def __imul__(self, *args, **kwargs):
        return _NoneType()
    def __imatmul__(self, *args, **kwargs):
        return _NoneType()
    def __itruediv__(self, *args, **kwargs):
        return _NoneType()
    def __ifloordiv__(self, *args, **kwargs):
        return _NoneType()
    def __imod__(self, *args, **kwargs):
        return _NoneType()
    def __ipow__(self, *args, **kwargs):
        return _NoneType()
    def __ilshift__(self, *args, **kwargs):
        return _NoneType()
    def __irshift__(self, *args, **kwargs):
        return _NoneType()
    def __iand__(self, *args, **kwargs):
        return _NoneType()
    def __ixor__(self, *args, **kwargs):
        return _NoneType()
    def __ior__(self, *args, **kwargs):
        return _NoneType()
    def __neg__(self, *args, **kwargs):
        return _NoneType()
    def __pos__(self, *args, **kwargs):
        return _NoneType()
    def __abs__(self, *args, **kwargs):
        return _NoneType()
    def __invert__(self, *args, **kwargs):
        return _NoneType()
    def __complex__(self, *args, **kwargs):
        return _NoneType()
    def __int__(self, *args, **kwargs):
        return _NoneType()
    def __float__(self, *args, **kwargs):
        return _NoneType()
    def __index__(self, *args, **kwargs):
        return _NoneType()
    def __round__(self, *args, **kwargs):
        return _NoneType()
    def __trunc__(self, *args, **kwargs):
        return _NoneType()
    def __floor__(self, *args, **kwargs):
        return _NoneType()
    def __ceil__(self, *args, **kwargs):
        return _NoneType()
